********* BENEFITS CALCULATION **********
/*
I model the following benefits:
 - maternity benefit
 - birth grant
 - child allowance
 - housing benefit
 - aid in material need (living allowance and housing supplement)
 
I do not model the following benefits:
- parental allowance
	- problematic because parents can now choose the monthly amount of parental allowance and thus the total length (with the max amount of CZK 11,500/month or max amount given by previous wage of one of the parents)
	- moreover, parents can change this each 3 months
	- we could assume that parents choose the highest amount possible (which would make sense economically), but:
		- it is not the case (only 6% of women were on the shortest track in 2011, which shows that people do not prefer the max amount for shorter time)
			- maybe because there are no nurseries and thus woman will stay at home longer than 2 years anyway, and choosing 2-years track would mean that in last year they get no alowance..
		- in case of lone mothers that have one year old (or older) child we do not see their previous wage and cannot thus calculate the max monhtly amount

- unemployment benefit:
	- short-term benefit
	- cannot assesss eligibility based on SILC data
		- individual needs to work at least 12 months out of last 24 months to be eligible
		- also unemployment benefit is collected only for 5 months (8 months for 50-55 years old, 11 months for 55 and older) and we do not know how long the person is unemployed
		- we only know from the data that a person is unemployed and whether he worked in past or not and how many years did he work

		
1. MINIMUM LIVING STANDARD FOR A HOUSEHOLD:
- Minimum living standard (MLS) of a household is used in calculating most of the welfare benefits.
- Law defines MLS for each person in the household, we need to take these amounts and sum them up for each HH in the data (taking into account the HH composition) to create the household MLS.
- The calculation of household MLS is pretty straightforward, but we need to first define properly the concept of "nezaopatrene dite" (which is a bit different from the one used for tax purposes):
	- Zakon 117/1995 Sb., o sttn sociln podpoe ( 11):
	(1) Za nezaopaten dt se pro ely tohoto zkona povauje dt do skonen povinn koln dochzky, a pot, nejdle vak do 26. roku vku, jestlie 
	a) se soustavn pipravuje na budouc povoln ( 12 a 15), nebo 
	b) se neme soustavn pipravovat na budouc povoln nebo vykonvat vdlenou innost pro nemoc nebo raz, anebo 
	c) z dvodu dlouhodob nepznivho zdravotnho stavu je neschopno vykonvat soustavnou vdlenou innost. 
	(2) Po skonen povinn koln dochzky se do 18. roku vku povauje za nezaopaten dt tak dt, kter je vedeno v evidenci krajsk poboky adu prce jako uchaze o zamstnn a nem nrok na podporu v nezamstnanosti nebo podporu pi rekvalifikaci
	(3) Za nezaopaten dt nelze vak povaovat dt, kter je poivatelem invalidnho dchodu z dchodovho pojitn pro invaliditu tetho stupn. 
 
	- assume there are no children aged 16-25 who are long-term ill, but do not get disability pension
	- assume there are no children aged 16-18 who are unemployed, but do not receive unemployment benefit (we do not want to define children based on eligibility for some benefit, because if there is a change in eligibility to these benefits, the definition of children would not be consistent)
		- in the SILC data variable "deti" also do not take into account this possibility (there are some HH in which unemployed 17 years old child is not considered in "deti" although the child does not receive unemployment benefit - domac 110003321) 
	- nezaop dite is therefore a child up to the age of 14, or a child between 15 and 25 who is a student (ea==6)
	
- I have compared the computed household MLS with the variable "zivmin" in the SILC data, and it fits quite well.
	- the only problem is with the 15-year old children that are inactive (ea==0), therefore I do not take them as nezaop deti and assign them value of mls_2adult (but in SILC they are in category d10_15 and therefore they are taken children in calculating MLS - although I think they should not be)
	- otherwise, it is OK (for example 16-year old inactive children are not considered to nezaop by me nor by SILC)


	
2. BIRTH GRANT
- "ben unit" for calculating birth grant eligibility
	- not the whole household (see creation of "benunit" in dataprocess, Zakon 117/1995 Sb., o sttn sociln podpoe,  7)
	- the same benunit as for child allowance purposes

- Income for eligibility for birth grant (Zakon 117/1995 Sb., o sttn sociln podpoe,  5)
	=> income is the same as for child allowance purposes, but it does not include parental allowance
	=> income tested is the income of the calendar quarter preceeding the quarter in which the child was born (Zakon 117/1995 Sb., o sttn sociln podpoe,  6)
	 - here we again assume that there are no big jumps in income over the year, because we calculate eligibility based on income form the whole year (first, we do not know in which quarter the child was born, second, we cannot assign income to quarters)

- Eligibility for birth grant:
	- for women that gave birth to their first child (for second and next children, there is no birth grant)
		- birth of first child in the benunit took place in the previous year = there are some children aged 0, and there are no older nezaop children in the ben unit
		- if there is more than one child aged 0, assume these are twins (triplets)
	- income of ben unit < (ben unit's MLS * birth grant coefficient)

- Amount of birth grant:
	- one child = 13000
	- twins or more = 19500
	
	
	
3. MATERNITY BENEFIT
Zkon . 187/2006 Sb., o nemocenskm pojitn
- Eligibility ( 32):
	- paying health insurance at the time of the start of maternity benefit 
	- employees: paying health insurance for at least 270 days out of the last 2 years
		- assume that if woman with child aged 0 worked last year for some positive number of months, she has been working before as well for at least 270 days in the last 2 years
		- also women that only worked for less than 270 days before maternity leave are eligible for maternity benefit if they attended high school or university right before that (school pays health insurance for them)
	- self-emplyed: paying health insurance for at least 180 days out of the last 2 years
		- assume that all self-employed women do pay health insurance, because it does pay off for them to do so

- Duration:
	- 28 weeks
	- 37 weeks for multiple births 
	- begins at the beginning of 8th/7th/6th week before the expected birth date

- Eligibility:
	- assign maternity benefit to each ben unit in which there is a child aged 0 and a woman who is a parent of that child and who had positive earnings in the last year

	
- Amount ( 18 and  18):
	- (maternity benefit coeffient * daily assessment base) per calendar day
	- daily assessment base is calculated as an average gross daily wage in the last 12 months (total gross wage divided by number of months divided by 30)
		- calculated based on gross wage (from the tax base for health insurance)
	- daily assessment base is further reduced 	: if day wage bwt first and second reduction base -> multiplied by first reduction coefficient
												: if day wage btw second and third reduction base -> multiplied by second reduction coefficient
												: if day wage higher than third reduction base -> not included into assessment base

	- calculate average day wage based on income from previous year (not necessarily the whole year - if women worked only 6 months last year, calculate it from those 6 months)
	- total amount of maternity benefit = daily amount * 7 days * 28 weeks
		- assign this total amount to the mother of a child
	
	
	
4. CHILD ALLOWANCE
- "ben unit" for calculating child allowance eligibility
	- not the whole household (see creation of "benunit" in dataprocess, Zakon 117/1995 Sb., o sttn sociln podpoe,  7)

- Income for calculating child allowance eligibility: (Zakon 117/1995 Sb., o sttn sociln podpoe,  5)
	=> income includes net income from work, pensions, sickness benefit, maternity benefit, parental allowance, unemployment benefit, rental income, and capital income
	- net income from work is at the individual level, sum it up over all members of benunit
	- for now, take the pensions, sickness benefit, maternity benefit, parental allowance, and unemployment benefit from the data (take reported values)
		- but we need these at the individual level as well, because the benunit is not always equivalent to the household
		- in the original SILC data, these are only at the household level - use additional data
		- I have first checked that the social benefits at the individual level in additional data correspond to household level variables in original data (and it indeed does - seems reasonable to use additional data)
		- thus, I change the underlying dataset used from "jextzp10.dta" to "jextzp10_all.dta" (the original data merged with additional)
	- rental income, capital income
		- these are also from the additional data
	
	=> income tested is always the income of the previous year (Zakon 117/1995 Sb., o sttn sociln podpoe,  6)
		- child allowance is assigned to the eligible family for the whole school year (from 1.9. of year x to 31.8. of year x+1) based on income from the previous calendar year (x-1)
		- this should not matter much, as in SILC the reported income is also from the previous calendar year
	
- Eligibility for child allowance:
	- income of ben unit < (ben unit's MLS * child allowance coefficient)
	
- Amount of child allowance:
	- fixed monthly amount per a child aged 0-5, 6-14, 15-25
	
	
5. HOUSING BENEFIT
- "ben unit" for calculating housing benefit consists of all people having the permanent residence in the flat
	- Zakon 117/1995 Sb., o sttn sociln podpoe ( 7, odst. 6):
	Jde-li o pspvek na bydlen, povauj se za rodinu vechny osoby, s vjimkou osob uvedench v odstavci 4, kter jsou v tme byt hleny k trvalmu pobytu;1a) podmnka, aby spolu trvale ily a spolen uhrazovaly nklady na sv poteby, se vak nevyaduje. 
	
	=> SILC includes all people that have usual residence in the household
	=> assume that if someone is in the given household in SILC, he has a permanent residence there 

- Income for calculating housing benefit:
	=> income includes net income from work, pensions, sickness benefit, maternity benefit, parental allowance, unemployment benefit, rental income, capital income, and child benefit
	=> income for housing benefit is the same as the one for child allowance, plus includes the child allowance	
	=> income tested is the income of the calendar quarter preceeding the quarter for which the housing benefit is assigned (Zakon 117/1995 Sb., o sttn sociln podpoe,  6)
	 - here we again assume that there are no big jumps in income over the year, because we calculate eligibility based on income from the whole year
	
- Eligibility for housing benefit:
	- normative housing cost >= actual housing cost > (income of HH * housing benefit coefficient)
	- housing benefit coefficient differs for Prague and out of Prague
	
- Amount of housing benefit:
	- min(actual housing cost; normative housing cost) - (housing benefit coefficient * max(income of HH, MLS of HH))
	- an individual can receive housing benefit for at most 84 months (7 years) within 10 calendar years
	- as it is based on income from previous calednar quarter, you have to ask submit confirmation of income each 3 months

	

6. AIDS IN MATERIAL NEED (LIVING ALLOWANCE + HOUSING SUPLEMENT)
- What is a "ben unit" for calculating aid in material need?
	Zkon 111/2006 Sb., o pomoci v hmotn nouzi ( 2):
	Pro ely posuzovn stavu hmotn nouze se pjmy a sociln a majetkov pomry osoby, kter d o dvku, posuzuj spolen s pjmy a socilnmi a majetkovmi pomry dalch osob. 
	Okruh tchto spolen posuzovanch osob se posuzuje podle zkona o ivotnm a existennm minimu2)
	
	Zkon 110/2006 Sb., o ivotnm a existennm minimu ( 4):
	Spolen se pro ely tohoto zkona, nen-li dle stanoveno jinak, posuzuj 
	a) rodie a nezletil nezaopaten dti, 
	b) manel nebo partnei podle zvltnho prvnho pedpisu2a); za partnera se pro ely tohoto zkona povauje tak partner, se kterm oban lenskho sttu Evropsk unie uzavel registrovan partnerstv na zklad prvnch pedpis jinho lenskho sttu Evropsk unie, pokud tyto prvn pedpisy upravuj vzjemnou vyivovac povinnost mezi partnery, 
	c) rodie a 
	1. nezletil dti, kter nejsou nezaopaten, 
	2. zletil dti, pokud tyto dti spolen s rodii uvaj byt a nejsou spolen posuzovny s jinmi osobami podle psmene b) nebo d), 
	d) jin osoby, kter spolen uvaj byt, s vjimkou osob, kter psemn prohls, e spolu trvale neij a spolen neuhrazuj nklady na sv poteby3) 

	=> ben unit consists of all people living in the HH (therefore it is equivalent ot the concept of "domacnost" in SILC) 
	=> there is no need to create ben unit
 
LIVING ALLOWANCE (prispevek na zivobyti):

- Income for living allowance purposes:
	Zkon 111/2006 Sb., o pomoci v hmotn nouzi ( 9, odst 1 & 2):
	= 70 % of net income from work (not including tax bonus) + 80% of unemployment benefits + 100% of other income (including: child allowance, pensions, sickness benefit, maternity benefit, parental allowance, NOT including: housing benefit) 
	- moreover, we deduct adequate housing cost from the income
		- adequate housing costs = min(real housing costs, living allowance coefficient * income)), where income is the income for living allowance purposes but without capital income
	
- Subsistence level (castka zivobyti):
	Zkon 111/2006 Sb., o pomoci v hmotn nouzi ( 24):
	- for working individuals and women at parental leave = existence minimu + 0.5*(MLS-existence minimum)
	- for nezaop children = MLS
	- for other HH members = existence minimum
	(here we assume that the other HH members do not fulfill other conditions ( 26), which would increase their subsistence level above existence minimum, such as: receiving living allowance for at most 3 months, having some assets which they can use to increase their income, etc. (these conditions are not possible to verify)

- Eligibility for living allowance: ( 21)
	- income for living allowance after deducting dequate housing cost is lower than subsistence level of HH 
	- but if average income of HH in the preceeding 3 months was higher than 3 * MLS of HH, the HH is not eligible
		- we work with income in the preceeding year, to which we apply the eligibility criterion  - therefore, the condition of average income in preceeding months being lower than 3*MLS should be satisfied unless there are some big jumps in the income level
			
- Amount of living allowance: ( 23)
	= subsistence level of HH - income for living allowance (income is after deducting dequate housing cost)
	- this is monthly amount - eligibility is checked each month based on confirmation of income for the previous month
	
	
HOUSING SUPPLEMENT (doplatek na bydleni):

- Income for housing suplement purposes:
	Zkon 111/2006 Sb., o pomoci v hmotn nouzi ( 9, odst 1 & 2):
	= income for living allowance purposes (before deducting adequate housing cost) + living allowance + housing benefit
	- moreover, we deduct real housing cost from the income (real housing cost = oduvodnene naklady na bydleni)

- Eligibility for housing suplement:
	1) anyone eligible for living allowance is automatically eligible for housing supplement - amount 1) ( 33, dost. 3 Zkona 111/2006 Sb., o pomoci v hmotn nouzi)
	2) if someone is not eligible for living allowance, but the income (for living allowance) does not exceeded 1.3*subsistence level (the HH is close to being eligible for living allowance)
		- in case 2 amount of housing suplement is lower - calculated based on reduced subsistence level (see amount no. 2)
	
- Amount of housing suplement:
	1) subsistence level of HH - income for housing suplement (from which we deducted real housing cost)
	2) reduced subsistence level of HH - income for housing suplement (from which we deducted real housing cost)
		- where reduced subsistence level is sum of:
			- existence minimums for all adults
			- MLSs for nezaop children
	- this is monthly amount - eligibility is checked each month based on confirmation of income for the previous month


*/

* Load the data, parameters, dataprocess, and computation of taxes
* do etbcompute

* Define the program
capture program drop bencompute

program bencompute
	args t datain dataout 	/* specify: t = tax regime, datain = input dataset, dataout = output dataset*/
	set more off
	cd output_`t'
	use `datain', clear

	
	***************************** CALCULATED BENEFITS ********************************
	
	
	*======================* MINIMUM LIVING STANDARD *======================*
	
	* create dummies for number of nezaop children 0-5, 6-14, 15-25 years old
	g d_5i = (vek<6)
	bysort domac: egen d_5 = total(d_5i)
	g d6_14i = (vek>5 & vek<15)
	bysort domac: egen d6_14 = total(d6_14i)
	g d15_25i = (vek>14 & vek<26 & ea==6) // variable studium seems to be better variable for determining nezaop children under 25, but in some cases studium==0 & ea==6 (which should not be the case - missing values in studium?) - use ea==6
	bysort domac: egen d15_25 = total(d15_25i)
	g deti2 =  d_5+ d6_14+ d15_25 // total number of nezaop deti, it differs a little bit from variable "deti"
	g deti2d = (deti2>0)
	
	* minimum living standard of the individual
	g 		mls_`t' = mls_1adult_`t' 		if vztah==1
	replace mls_`t' = mls_5child_`t' 		if d_5i
	replace mls_`t' = mls_6_14child_`t' 	if d6_14i
	replace mls_`t' = mls_15_25child_`t' 	if d15_25i
	replace mls_`t' = mls_2adult_`t' 		if mls_`t'==.
	replace mls_`t' = mls_onep_`t' 		if osob==1

	* minimum living standard for the ben unit
	bysort benunit: egen mls_unit_`t' = total(mls_`t')
	
	* minimum living standard for the household
	bysort domac: egen mls_hh_`t' = total(mls_`t')
	
	/* checking that the computed mls_hh corresponds to the variable "zivmin" (monthly) in the SILC data for "c" parameters
	gen zivmin_y = zivmin*12
	sum mls_hh_c zivmin_y 
	bysort domac: gen n = _n
	sum domac if mls_hh_c!=zivmin_y & vztah==1 //222 households for which our calculated MLS differs from the one in SILC
	sum domac if mls_hh_c!=zivmin_y & vek==15 & ea==0 //215 of these households has a 15-year old child who is inactive in the HH - I do not take them as nezaop deti and assign them value of mls_2adult (but in SILC they are in category d10_15 and therefore they are taken children in calculating MLS
	*/
	
	
		
	*======================* BIRTH GRANT *======================* 
	
	* income for calculating birth grant eligibility
	gen inc_bg_`t' = netinc_`t' + duch_s + duch_v + duch_i + duch_si + nemoc + pnezam + p_majet + p_jine //generate this income at the individual level
	bysort benunit: egen inc_bgunit_`t' = total(inc_bg_`t') if benunit!="0" // ben unit - level income
	label variable inc_bgunit_`t' "Income of the ben unit for birth grant purposes"
	
	* eligibility
	* dummy for first child in a ben unit (there are no older children) being born this year (aged 0)
	bysort benunit: egen child0 = total(vek==0) if benunit!="0" //number of children aged 0 in the ben unit - 98 ben units with one such child, 3 ben units with two such children (twins)
	bysort benunit: egen child1_ = total(vek>0 & nezaop==1) if benunit!="0" //number of nezaop children aged 1 or more in the ben unit
	gen first_child0 = (child0>0 & child1_==0) // dummy for first child in the ben unit being born during the previous year
	* before 2011, birth grant was also for second and following chiddren
	replace first_child0 = 1 if brth_gr_frstch_`t'==0 //make condition for firts child satisfied (=1) automatically if mat_ben_frstch_`t'==0
	
	* calculating birth grant
	gen	 	brth_gr_`t' = 0									if benunit!="0"
	replace brth_gr_`t' = brth_gr_`t' + b_gr_1ch_`t'   		if child0==1 & first_child0==1 & inc_bgunit_`t' < b_gr_elig_`t' * mls_unit_`t' //one child born in the last year and it is the first child in the ben unit
	replace brth_gr_`t' = brth_gr_`t' + b_gr_twins_`t'	 	if child0==2 & first_child0==1 & inc_bgunit_`t' < b_gr_elig_`t' * mls_unit_`t' //two children (suppose twins) born in the last year and it is the first child in the ben unit
	replace brth_gr_`t' = brth_gr_`t' + b_gr_tripl_`t'		if child0==3 & first_child0==1 & inc_bgunit_`t' < b_gr_elig_`t' * mls_unit_`t' //three children (triplest) born in the last year and it is the first child in the ben unit
	replace brth_gr_`t' = 0 if benhead==0 //value of birth grant is assigned to benhead only
	
	
		
	*======================* MATERNITY BENEFIT *======================* 

	* assessment base
	* average gross daily wage in the last year (calculated only based on those months in which woman worked)
	gen 	ginc_daily = ginc_w / (mes_zam*30)	if mes_zam>0 & ginc_w>0 & ginc_b==0
	replace ginc_daily = ginc_b / (mes_podn*30)	if mes_podn>0 & ginc_b>0 & ginc_w==0
	replace ginc_daily = (ginc_w/(mes_zam*30)) + (ginc_b/(mes_podn*30)) if mes_zam>0 & mes_podn>0 & ginc_w>0 & ginc_b>0

	
	* reduced daily income creates an assessment base
	gen 	ass_base_`t' = ginc_daily																										if ginc_daily > 0 & ginc_daily <= mat_ben_1rb_`t'
	replace ass_base_`t' = mat_ben_1rb_`t' + (ginc_daily-mat_ben_1rb_`t')*mat_ben_1rc_`t'														if mat_ben_1rb_`t' < ginc_daily & ginc_daily <= mat_ben_2rb_`t'
	replace ass_base_`t' = mat_ben_1rb_`t' + (mat_ben_2rb_`t'-mat_ben_1rb_`t')*mat_ben_1rc_`t' + (ginc_daily-mat_ben_2rb_`t')*mat_ben_2rc_`t'		if mat_ben_2rb_`t' < ginc_daily & ginc_daily <= mat_ben_3rb_`t'
	replace ass_base_`t' = mat_ben_1rb_`t' + (mat_ben_2rb_`t'-mat_ben_1rb_`t')*mat_ben_1rc_`t' + (mat_ben_3rb_`t'-mat_ben_2rb_`t')*mat_ben_2rc_`t'	if ginc_daily > mat_ben_3rb_`t' & ginc_daily!=.

	* dummy for a mother of child aged 0 (woman that collects maternity benefit)
		* only for 2 cases in which we can certainly distinguish who is a mother of a child - child has vztah=3 | 5 (there are two children with vztah==8 left unassigned to any mother - no one gets moternity benefit for them, because it is not clear who the mother is)
	gen childhead0 = (vek==0 & vztah==3)
	bysort domac: egen childhead0hh = total(childhead0)
	gen grandchildhead0 = (vek==0 & vztah==5)
	bysort domac: egen grandchildhead0hh = total(grandchildhead0)
	
	gen daughterparent = 1 if vztah == 3 & rodic == 1 & pohl==2
	by domac: egen daughterparenthh = count(daughterparent)
	gen sonparent = 1 if vztah == 3 & rodic == 1 & pohl==1
	by domac: egen sonparenthh = count(sonparent)
	gen daughterILparent = 1 if vztah == 4 & rodic == 1 & pohl==2
	by domac: egen daughterILparenthh = count(daughterILparent)
	
	* mother of a child aged 0
	gen 	mother = 1 if vztah == 1 & rodic == 1 & pohl==2 & childhead0hh>0
	replace	mother = 1 if vztah == 2 & rodic == 1 & pohl==2 & childhead0hh>0
	replace mother = 1 if grandchildhead0hh>0 & daughterparenthh==1 & daughterparent==1    //daugher of head is a mother of child if there is only one daughter of head being parent
	replace mother = 1 if grandchildhead0hh>0 & sonparenthh==1 & daughterILparenthh==1 & daughterILparent==1 //daugher in law is a mother  of a grandchild of head if there is exactly one son of head who is a parent and excatly one daughter in law who is a parent
	
	bysort benunit: egen motherhh = total(mother)
	
	* total amount of maternity benefit - assigned to the mother
	* coefficient * daily assessment base of the mother * 7 * number of weeks 
	gen 	mat_ben_`t' = mat_ben_coef_`t' * ass_base_`t' * 7 * mat_ben_1dur_`t'	if child0==1 & mother==1 // one child born to a woman 
	replace mat_ben_`t' = mat_ben_coef_`t' * ass_base_`t' * 7 * mat_ben_2dur_`t'	if child0>1  & mother==1 // multiple children born
	replace mat_ben_`t' = 0														if mat_ben_`t'==. // replace . by 0, because we will have to sum it with other sources of income
 
	
	*======================* CHILD ALLOWANCE *======================*
	
	* income for calculating child allowance eligibility: net income from work, pensions, sickness benefit, maternity benefit, parental allowance, and unemployment benefit
	gen inc_ch_`t' = netinc_`t' + duch_s + duch_v + duch_i + duch_si + nemoc + mat_ben_`t' + rodp + pnezam + p_majet + p_jine //generate this income at the individual level
	bysort benunit: egen inc_chunit_`t' = total(inc_ch_`t') if benunit!="0" // ben unit - level income
	label variable inc_chunit_`t' "Income of the ben unit for child allowance purposes"
	
	* calculating child allowance
	gen	 	ch_all_`t' = 0											if benunit!="0"
	replace ch_all_`t' = ch_all_`t' + ch_all_5ch_`t' * d_5   			if d_5>0    & inc_chunit_`t' < ch_all_elig_`t' * mls_unit_`t'
	replace ch_all_`t' = ch_all_`t' + ch_all6_14ch_`t' * d6_14	 		if d6_14>0  & inc_chunit_`t' < ch_all_elig_`t' * mls_unit_`t'
	replace ch_all_`t' = ch_all_`t' + ch_all15_25ch_`t' * d15_25		if d15_25>0 & inc_chunit_`t' < ch_all_elig_`t' * mls_unit_`t'
	replace ch_all_`t' = 0 if benhead==0 //value of child benefit is assigned to benhead only
	
	
	
	*======================* HOUSING BENEFIT *======================*
	* housing cost (both actual and normative) are monthly, we need yearly:	
	replace norm_naklady_`t' = norm_naklady_`t' * 12 
	gen naklady_y 	 = naklady * 12
	* income housing benefit calculation
	gen inc_hb_`t' = inc_ch_`t' + ch_all_`t'
	bysort domac: egen inc_hbhh_`t' = total(inc_hb_`t')
	replace inc_hbhh_`t' = inc_hbhh_`t' + jine_socp // jine socialni prijmy - neni na urovni jednotlivcu
	label variable inc_hbhh_`t' "Income of the household for housing benefit purposes"

	* housing benefit calculation
	g hous_ben_`t' = 0
	replace hous_ben_`t' = max( min(naklady_y, norm_naklady_`t') - (hous_ben_coef_`t' 		* max(inc_hbhh_`t',mls_hh_`t')), 0) if typ!=1 /*typ!=1 is out of Prague*/
	replace hous_ben_`t' = max( min(naklady_y, norm_naklady_`t') - (hous_ben_coef_Pr_`t' 	* max(inc_hbhh_`t',mls_hh_`t')), 0) if typ==1 /*typ==1 is Prague*/
	replace hous_ben_`t' = 0 if vztah!=1	//value of housing benefit is assigned to head of HH
	
	
					
	*======================* AID IN MATERIAL NEED *======================*

	***** LIVING ALLOWANCE *****
	* subsistence level 
	gen 	subslevel_`t' = ex_min_`t' + 0.5*(mls_`t'-ex_min_`t')   if ((ea>0 & ea<5) | rodp>0)  // for working and women on parental leave
	replace subslevel_`t' = mls_`t'  								if nezaopb==1  // for children
	replace subslevel_`t' = ex_min_`t'							if subslevel_`t'==.  // for other HH members
	bysort domac: egen subslevelhh_`t' = total(subslevel_`t')
	label variable subslevelhh_`t' "Amount of subsistence level for the household"

	* income for living allowance purposes
	gen inc_liv_`t' 	= 0.7*netinc_`t' + 0.8*pnezam + duch_s + duch_v + duch_i + duch_si + rodp + nemoc + mat_ben_`t' + ch_all_`t' + p_majet + p_jine // living allowance income before deducting adequate housing cost
	bysort domac: egen inc_livhh_`t'  = total(inc_liv_`t') 
		gen inc_hous_`t' = inc_liv_`t' - p_majet // income for adequate housing cost calculation (the same as above but without capital income)
	bysort domac: egen inc_houshh_`t' = total(inc_hous_`t')  
	replace inc_livhh_`t' = inc_livhh_`t' -  min(naklady_y, liv_all_coef_`t'    * inc_houshh_`t') if typ!=1 //deducting adequate housing costs (not Prague)
	replace inc_livhh_`t' = inc_livhh_`t' -  min(naklady_y, liv_all_coef_Pr_`t' * inc_houshh_`t') if typ==1 //deducting adequate housing costs (Prague)
	replace inc_livhh_`t' = inc_livhh_`t' + jine_socp // jine socialni prijmy - neni na urovni jednotlivcu
	label  variable inc_livhh_`t' "Income of the household for living allowance purposes"

	* living allowance amount
	gen     liv_all_`t' = 0		
	replace liv_all_`t' = max(0, subslevelhh_`t' - inc_livhh_`t') if inc_livhh_`t' < subslevelhh_`t' 
	replace liv_all_`t' = 0 if vztah!=1	//value of living allowance is assigned to head of HH
	label variable liv_all_`t' "Amount of living allowance for the HH"

	
	***** HOUSING SUPPLEMENT *****
	* reduced subsistence level
	gen 	subslevelred_`t' = ex_min_`t' if nezaopb==0 // for all but nezaop children
	replace subslevelred_`t' = mls_`t'  	if nezaopb==1  // for nezaop children
	bysort domac: egen subslevelredhh_`t' = total(subslevelred_`t')
	label variable subslevelredhh_`t' "Amount of reduced subsistence level for the household"
		
	* income for housing supplement purposes
	gen 	inc_hs_`t' = inc_liv_`t' + liv_all_`t' + hous_ben_`t' // income before deducting real housing cost (income for living allowance + living allowance & housing benefit - these are asigned to head of HH only, so that it is OK to sum up the income over domac in next step)
	bysort domac: egen inc_hshh_`t'  = total(inc_hs_`t')
	replace inc_hshh_`t' = inc_hshh_`t' - naklady_y //deducting real housing cost
	replace inc_hshh_`t' = inc_hshh_`t' + jine_socp // jine socialni prijmy - neni na urovni jednotlivcu
	label  variable inc_hshh_`t' "Income of the household for housing supplement purposes"

	* amount of housing supplement
	gen     hous_supl_`t' = 0		
	replace hous_supl_`t' = max(0, subslevelhh_`t'    - inc_hshh_`t')	if inc_livhh_`t' <= subslevelhh_`t' // case 1) - eligible for living allowance
	replace hous_supl_`t' = max(0, subslevelredhh_`t'	- inc_hshh_`t')	if inc_livhh_`t' > subslevelhh_`t' & inc_livhh_`t' <= 1.3*subslevelhh_`t' // case 2) - not eligible for living allowance
	replace hous_supl_`t' = 0 if vztah!=1	//value of housing supplement is assigned to head of HH
	label variable hous_supl_`t' "Amount of housing supplement for the HH"
	

		
	
	
*======================* TOTAL AMOUNT OF BENEFITS *======================*
	
	* rename reported benefits at individual level
	gen unempl_ben_`t' = pnezam /*unemployment benefit only reported, not possible to calculate*/
	gen par_all_`t' = rodp /*parental allowance only reported, not possible to calculate*/
	
	* the only benefit not at individual level is "jine_socp" (other social benefits at HH level), assign it to head of HH
	* outlier in jine_socp = 1 116 000 - replace by 0 (jine_socp zahrnuje pspvek na pi (u neexistuje), vsluhov pspvek, odchodn, pspvky pro tce zdravotn postien obany)
	gen other_ben_`t' = jine_socp if vztah==1
	replace other_ben_`t' = 0  if (vztah!=1 | jine_socp > 1000000)
	
	* create benefits at HH level (calculated)
	bysort domac: egen brth_grhh_`t'  = total(brth_gr_`t')
	bysort domac: egen mat_benhh_`t'  = total(mat_ben_`t')
	bysort domac: egen ch_allhh_`t'  = total(ch_all_`t')
	bysort domac: egen hous_benhh_`t'  = total(hous_ben_`t')
	bysort domac: egen liv_allhh_`t'  = total(liv_all_`t')
	bysort domac: egen hous_suplhh_`t'  = total(hous_supl_`t')
	gen mat_needhh_`t' = hous_suplhh_`t' + liv_allhh_`t' 
	
	* rename reported benefits at HH level - these cannot be calculated, so we will use the reported values
	gen unempl_benhh_`t' = pnezam_hh
	gen par_allhh_`t'  = rodp_hh
	gen other_benhh_`t' = jine_socp // jin sociln prijmy (at HH level) - includes pspvek na pi (u neexistuje), vsluhov pspvek, odchodn, pspvky pro tce zdravotn postien obany
 	replace other_benhh_`t' = 0 if jine_socp > 1000000 //outlier
	
	***** TOTAL CALCULATED BENEFITS
	* at individual level - benefits assigned to mother in case of maternity benefit, assigned to head of ben unit in case of birth grant and child allowance, assigned to person who reported it in case of unemployment benefits and parental allowance, assigned to head of HH in case of other benefits
	gen totalben_`t' = brth_gr_`t' + mat_ben_`t' + ch_all_`t' + hous_ben_`t' + liv_all_`t' + hous_supl_`t' + unempl_ben_`t' + par_all_`t' + other_ben_`t'
	label variable totalben_`t' "Total benefits, calculated (at individual level) taxsystem `t'" 
	* at HH level
	gen hhtotalben_`t' = brth_grhh_`t' + mat_benhh_`t' + ch_allhh_`t' + hous_benhh_`t' + liv_allhh_`t' + hous_suplhh_`t' + unempl_benhh_`t' + par_allhh_`t' + other_benhh_`t'
	label variable hhtotalben_`t' "Total benefits, calculated (at HH level) taxsystem _`t'" 
	
	***** NET INCOME AFTER TAX AND WITH BENEFITS
	gen hhnetinc_`t' = hhaftertinc_`t' + hhtotalben_`t'
	label variable hhnetinc_`t' "Net household income after taxes and benefits _`t'" 
	* gross income with benefits (without taxes)
	gen hhbeninc_`t' = hhginc_i + hhtotalben_`t'
	
		
	****************************** TOTAL REPORTED BENEFITS (suffix c) ********************************
	* rename reported benefits at individual level
	gen mat_ben_c = nemoc /*nemoc includes not only maternity benefit, but also sickness benefits*/
	gen unempl_ben_c = pnezam /*unemployment benefit only reported, not possible to calculate*/
	gen par_all_c = rodp /*parental allowance only reported, not possible to calculate*/
	
	* create benefits at individual level from reported HH level variables - assign it to head
	gen brth_gr_c = ost_dav if vztah==1 /*ost_dav includes not only birth grant, but also funeral benefit*/
	gen ch_all_c = pridav  if vztah==1
	gen hous_ben_c = pbydl if  vztah==1
	gen mat_need_c = hm_nouze  if vztah==1
	gen other_ben_c = jine_socp  if vztah==1 //jin sociln prijmy (at HH level) - includes pspvek na pi (u neexistuje), vsluhov pspvek, odchodn, pspvky pro tce zdravotn postien obany
		replace brth_gr_c = 0  if vztah!=1
		replace ch_all_c = 0  if vztah!=1
		replace hous_ben_c = 0  if vztah!=1
		replace mat_need_c = 0  if vztah!=1
		replace other_ben_c = 0  if (vztah!=1 | jine_socp > 1000000) // outlier jine_socp==1 116 000
	
	* rename reported benefits at HH level
	gen brth_grhh_c = ost_dav /*ost_dav includes not only birth grant, but also funeral benefit*/
	gen ch_allhh_c = pridav
	gen hous_benhh_c = pbydl
	gen mat_needhh_c = hm_nouze
	gen mat_benhh_c = nemoc_hh
	gen unempl_benhh_c = pnezam_hh
	gen par_allhh_c = rodp_hh
	gen other_benhh_c = jine_socp // jin sociln prijmy (at HH level) - includes pspvek na pi (u neexistuje), vsluhov pspvek, odchodn, pspvky pro tce zdravotn postien obany
 	replace other_benhh_c = 0 if jine_socp > 1000000 //outlier jine_socp==1 116 000

	
	***** TOTAL REPORTED BENEFITS
	* at individual level - benefits assigned to the person hwo reports them in case of maternity benefit (all sickness benefits), unemployment benefits, and parental leave, assigned to head of HH in case of other benefits
	gen totalben_c = brth_gr_c + ch_all_c + hous_ben_c + mat_ben_c +  mat_need_c + unempl_ben_c + par_all_c + other_ben_c
	label variable totalben_c "Total benefits, reported in SILC (at individual level)" 
	* at HH level
	gen hhtotalben_c = brth_grhh_c + ch_allhh_c + hous_benhh_c + mat_benhh_c +  mat_needhh_c + unempl_benhh_c + par_allhh_c + other_benhh_c
	label variable hhtotalben_c "Total benefits, reported in SILC (at HH level)" 
	


**** TAKE INTO ACCOUNT NON-TAKE-UP ******
	local bentypes "hous_ben mat_need" 
	foreach x of local bentypes {
	capture gen takeup_`x'=1 //this is here only because in the first run of the model, takeup* variables are not created and the file thus gives error here
	replace `x'hh_`t'  = 0 if takeup_`x'==0
	}
	* replace living allowance and housing allowance with zero if material need was replace with zero
	replace liv_allhh_`t' = 0 	if takeup_mat_need==0
	replace hous_suplhh_`t' = 0 if takeup_mat_need==0
	
	***** REPLACE TOTAL CALCULATED BENEFITS
	* at HH level
	replace hhtotalben_`t' = brth_grhh_`t' + mat_benhh_`t' + ch_allhh_`t' + hous_benhh_`t' + liv_allhh_`t' + hous_suplhh_`t' + unempl_benhh_`t' + par_allhh_`t' + other_benhh_`t'
	
	***** NET INCOME AFTER TAX AND WITH BENEFITS
	replace hhnetinc_`t' = hhaftertinc_`t' + hhtotalben_`t'
	replace hhbeninc_`t' = hhginc_i + hhtotalben_`t'

	
save `dataout', replace
cd ..
end

	

*======================* CONSISTENCY CHECKS *======================*
*run bencompute for tax system = z to compare reported values in SILC (c) and those calculated for the same time (z)
* compare calculated benefits from the time of data collection (z) with reported benefits from SILC (c)
* main problem - we assign benefits based on situation at the time of data collection (and based on income from previous year), but the reported benefits are those received in the year before the data collection (so the eligibility is often based on income two years before data colection - we do not know that)
*-if there are any significant income shocks etc., the consistency checks wont work

********** BIRTH GRANT *************
* calculated - at IND level (brth_gr)
	* it needs to be sum up over the whole HH (to be comparable with reported values at HH level)
* reported - birth grant is put together with funeral benefit (ost_dav) at HH level
	* funeral benefit is a fixed amount of 5000 CZK
	* if the reported values of birth grant differ by 5000 CZK (or some multiple) it is OK

	
********** MATERNITY BENEFIT ********** 
* calculated - at IND level (mat_ben)
* reported - maternity benefit put together with other benefits paid from health insurance 
	* at IND level (nemoc)	

	
********** CHILD ALLOWANCE *************
* calculated - at IND level (ch_all)
	* sum up over the HH to check consistency
* reported - only at HH level (variable pridav)
	

********** HOUSING BENEFIT ********** 
* calculated - at IND level (hous_ben)
	* sum up over the HH to check consistency
* reported - at HH level (pbydl)


********** AID IN MATERIAL NEED ********** 
* calculated - at IND level (liv_all and hous_supl)
	* sum up liv_all and hous_supl
	* sum up over the HH to check consistency
* reported - at HH level (hm_nouze)

*cd "X:\PROJECTS\TACR\calculations\graphs"


capture program drop bencheck

program bencheck
	args datain dataout 	/* specify: t = tax regime, datain = input dataset, dataout = output dataset*/
	set more off
	use `datain', clear

	* for HH/level benefits - plot the amount of benefit (or deviation) against household level gross income
	bysort domac: egen ginc_i_hh = total(ginc_i)
	label variable ginc_i_hh "Household gross income (business plus work)"


	****** BIRTH GRANT ******
	* at HH level

	* how many mothers of children aged 0 have positive birth grant reported and how many computed
	tab  brth_grhh_c  if mother==1 & brth_grhh_c>0
	tab  brth_grhh_z  if mother==1

	sum brth_grhh_c if brth_grhh_c>0 & mother==1
	sum brth_grhh_z if brth_grhh_z>0 & mother==1
	sum brth_grhh_c if brth_grhh_c>0 & brth_grhh_z==0 & mother==1
	sum brth_grhh_z if brth_grhh_z>0 & brth_grhh_c==0 & mother==1

	* deviations 
	gen brth_gr_deva = brth_grhh_z - brth_grhh_c 					if (brth_grhh_c>0 | brth_grhh_z>0)
	gen brth_gr_devp = (brth_grhh_z - brth_grhh_c)/brth_grhh_c*100 if (brth_grhh_c>0 | brth_grhh_z>0)
	label variable brth_gr_deva "Birth grant - absolute deviation"
	label variable brth_gr_devp "Birth grant- percentage deviation"

	tab brth_gr_deva  if mother==1

	* graph absolute deviation
	scatter brth_gr_deva ginc_i if mother==1 & (brth_grhh_c>0 | brth_grhh_z>0), saving(brth_gr_deva, replace) graphregion(color(white) lwidth(large)) title("Birth grant") subt("Absolute difference")

	* graph distribution
	count if (brth_grhh_c>0 | brth_grhh_z>0)  & mother==1
	twoway histogram brth_grhh_c if brth_grhh_c>0 & mother==1 [fweight=round(pkoef)], start(0) width(1000)  percent fintensity(inten80) lpattern(solid) fcolor(dkorange) lcolor(dkorange) legend(label(1 "Reported"))  || histogram brth_grhh_z if brth_grhh_z>0 & mother==1 [fweight=round(pkoef)], start(0) width(1000) percent fintensity(inten100) barwidth(500) legend(label(2 "Calculated")) fcolor(emidblue) lcolor(edkblue) graphregion(color(white) lwidth(large)) ytitle("percent") xtitle(, margin(top)) title("Birth grant distribution") subtitle("`r(N)' observations")

		
		
	****** MATERNITY BENEFIT ******
	* at IND level
	
	* compare only for mothers of children aged==0 (mother==1 - variable for a mother of a new born child)

	* how many mothers have positive maternity benefit reported and how many computed
	sum mat_ben_c if mat_ben_c>0 & mother==1
	sum mat_ben_z if mat_ben_z>0 & mother==1

	sum mat_ben_c if mat_ben_c>0 & mat_ben_z==0 & mother==1
	sum mat_ben_z if mat_ben_z>0 & mat_ben_c==0 & mother==1

	* deviations 
	gen mat_ben_deva = mat_ben_z - mat_ben_c 					if (mat_ben_c>0 | mat_ben_z>0)
	gen mat_ben_devp = (mat_ben_z - mat_ben_c / mat_ben_c)*100 if (mat_ben_c>0 | mat_ben_z>0)
	label variable mat_ben_deva "Maternity benefit - absolute deviation"
	label variable mat_ben_devp "Maternity benefit - percentage deviation"

	* graph absolute deviation
	scatter mat_ben_deva ginc_i if (mat_ben_c>0 | mat_ben_z>0), saving(mat_ben_deva1, replace) graphregion(color(white) lwidth(large)) title("Maternity benefit") subt("Absolute difference, all subjects")
	scatter mat_ben_deva ginc_i if (mat_ben_c>0 | mat_ben_z>0) & mat_ben_deva<50000 & mat_ben_deva>-50000, saving(mat_ben_deva2, replace) graphregion(color(white) lwidth(large)) title("Maternity benefit") subt("Absolute difference, all subjects, if diff<50,000")
	scatter mat_ben_deva ginc_i if (mat_ben_c>0 | mat_ben_z>0) & mother==1, saving(mat_ben_deva3, replace) graphregion(color(white) lwidth(large)) title("Maternity benefit") subt("Absolute difference, mothers of newborns only")

	* graph relative deviation
	scatter mat_ben_devp ginc_i if (mat_ben_c>0 | mat_ben_z>0) , saving(mat_ben_devp1, replace) graphregion(color(white) lwidth(large)) title("Maternity benefit") subt("Percentage difference, all subjects")
	scatter mat_ben_devp ginc_i if (mat_ben_c>0 | mat_ben_z>0) & mat_ben_devp<500, saving(mat_ben_devp2, replace) graphregion(color(white) lwidth(large)) title("Maternity benefit") subt("Percentage difference, all subjects, if diff<500%")
	scatter mat_ben_devp ginc_i if (mat_ben_c>0 | mat_ben_z>0) & mother==1 , saving(mat_ben_devp3, replace) graphregion(color(white) lwidth(large)) title("Maternity benefit") subt("Percentage difference, mothers of newborns only")


	* graph distribution
	count if (mat_ben_c>0 | mat_ben_z>0) & mother==1
	twoway histogram mat_ben_c if mat_ben_c>0 & mother==1 [fweight=round(pkoef)], start(0) width(4000)  percent fintensity(inten80) lpattern(solid) fcolor(dkorange) lcolor(dkorange) legend(label(1 "Reported"))  || histogram mat_ben_z if mat_ben_z>0 & mother==1 [fweight=round(pkoef)], start(0) width(4000) percent fintensity(inten100) barwidth(2000) legend(label(2 "Calculated")) fcolor(emidblue) lcolor(edkblue) graphregion(color(white) lwidth(large)) ytitle("percent") xtitle(, margin(top)) title("Maternity benefit distribution") subtitle("`r(N)' observations")



	****** CHILD ALLOWANCE ******
	* at HH level
	
	* how many HH have positive child allowance reported and how many computed
	sum ch_allhh_c if vztah==1 & ch_allhh_c>0
	sum ch_allhh_z if vztah==1 & ch_allhh_z>0

	sum ch_allhh_c if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0
	sum ch_allhh_z if vztah==1 & ch_allhh_z>0 & ch_allhh_c==0

	* those with positive reported allowance, but zero calculated
		tab ginc_i_hh if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0
		sum mls_hh if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0 & mls_hh*2.4 < ginc_i_hh /*most of these indeed have income above 2.4*mls*/
		* first group of HH with older children (15-26) - they are now not eligible (children working or unemployed), but they might be a year ago
		tab d6_14 d_5 if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0
		* second group of HHs who has also younger children - why do we not assign them the benefit? (high income?)
		sum domac if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0 & (d_5>0 | d6_14>0)
		sum domac if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0 & (d_5>0 | d6_14>0) & mls_hh*2.4 < ginc_i_hh // half of them have income from work already above the threshold
		sum domac if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0 & (d_5>0 | d6_14>0) & 2.4*mls_unit_z > inc_chunit_z // none of them have income below the threshold - it is OK...
		* vek nejmladsiho ditete
		gen 	d_vek = vek1d if deti==1
		replace d_vek = vek2d if deti==2
		replace d_vek = vek3d if deti==3
		replace d_vek = vek4d if deti==4
		replace d_vek = vek5d if deti==5
		replace d_vek = vekdd if deti==6
		tab d_vek if vztah==1 & ch_allhh_c>0 & ch_allhh_z==0 & (d_5>0 | d6_14>0)

	* those with positive calculated allowance, but zero reported
		sum domac if vztah==1 & ch_allhh_z>0 & ch_allhh_c==0
		tab deti if vztah==1 & ch_allhh_z>0 & ch_allhh_c==0
		tab d6_14 d_5 if vztah==1 & ch_allhh_c==0 & ch_allhh_z>0
		tab vek if ch_allhh_z>0 & ch_allhh_c==0 & deti==0 //some of these are households of students that do not apply for child allowance or maybe their parents do get them 
		tab ginc_i_hh if vztah==1 & ch_allhh_z>0 & ch_allhh_c==0 & deti>0
		list domac if vztah==1 & ch_allhh_z>0 & ch_allhh_c==0 & deti>0 & ginc_i_hh==0 //these are HH that would definitely be eligible for child allowance...
			
	* deviations
	gen ch_all_deva = ch_allhh_z - ch_allhh_c  				if (ch_allhh_c>0 | ch_allhh_z>0)
	gen ch_all_devp = (ch_allhh_z - ch_allhh_c)/ch_allhh_c*100 if (ch_allhh_c>0 | ch_allhh_z>0)
	label variable ch_all_deva "Child allowance - absolute deviation"
	label variable ch_all_devp "Child allowance - percentage deviation"

	tab ch_all_deva if vztah==1
	tab ch_all_devp if vztah==1

	* graph absolute deviation
	scatter ch_all_deva ginc_i_hh if vztah==1 & (ch_allhh_c>0 | ch_allhh_z>0), saving(ch_all_deva1, replace) graphregion(color(white) lwidth(large)) title("Child allowance") subt("Absolute difference")
	scatter ch_all_deva ginc_i_hh if vztah==1 & (ch_allhh_c>0 | ch_allhh_z>0) & ch_all_deva>-50000, saving(ch_all_deva2, replace) graphregion(color(white) lwidth(large)) title("Child allowance") subt("Absolute difference, if diff>-50,000")
	* graph relative deviation
	scatter ch_all_devp ginc_i_hh if vztah==1 & (ch_allhh_c>0 | ch_allhh_z>0), saving(ch_all_devp, replace) graphregion(color(white) lwidth(large)) title("Child allowance") subt("Percentage difference")

	* graph distribution
	count if (ch_allhh_c>0 | ch_allhh_z>0) & vztah==1
	twoway histogram ch_allhh_c if ch_allhh_c>0 & vztah==1 [fweight=round(pkoef)], start(0) width(800)  percent fintensity(inten80) lpattern(solid) fcolor(dkorange) lcolor(dkorange) legend(label(1 "Reported"))  || histogram ch_allhh_z if ch_allhh_z>0 & vztah==1 [fweight=round(pkoef)], start(0) width(800) percent fintensity(inten100) barwidth(400) legend(label(2 "Calculated")) fcolor(emidblue) lcolor(edkblue) graphregion(color(white) lwidth(large)) ytitle("percent") xtitle(, margin(top)) title("Child allowance distribution") subtitle("`r(N)' observations")
	count if (ch_allhh_c>0 | ch_allhh_z>0) & vztah==1 & ch_allhh_c<50000 
	twoway histogram ch_allhh_c if ch_allhh_c>0 & ch_allhh_c<50000 & vztah==1 [fweight=round(pkoef)], start(0) width(800)  percent fintensity(inten80) lpattern(solid) fcolor(dkorange) lcolor(dkorange) legend(label(1 "Reported"))  || histogram ch_allhh_z if ch_allhh_z>0 & vztah==1 [fweight=round(pkoef)], start(0) width(800) percent fintensity(inten100) barwidth(400) legend(label(2 "Calculated")) fcolor(emidblue) lcolor(edkblue) graphregion(color(white) lwidth(large)) ytitle("percent") xtitle(, margin(top)) title("Child allowance distribution") subtitle("`r(N)' observations, without 4 observations of reported benefit>50000")


	****** HOUSING BENEFIT ******
	* at HH level

	* how many HH have positive housing benefit reported and how many computed
	sum hous_benhh_c if vztah==1 & hous_benhh_c>0
	sum hous_benhh_z if vztah==1 & hous_benhh_z>0

	sum hous_benhh_c if vztah==1 & hous_benhh_c>0 & hous_benhh_z==0
	sum hous_benhh_z if vztah==1 & hous_benhh_z>0 & hous_benhh_c==0

	* those with positive calculated benefit, but zero reported
		tab ginc_i_hh if vztah==1 & hous_benhh_z>0 & hous_benhh_c==0 // 73% of these has zero household working income
		tab dom_oecd if vztah==1 & hous_benhh_z>0 & hous_benhh_c==0 // because these are mainly households of pensioners and unemployed...
		sum ginc_i_hh if vztah==1 & hous_benhh_z>0 & hous_benhh_c==0 & (dom_oecd==1 | dom_oecd==3) // the rest are household with low income...
		sum inc_hbhh_z if vztah==1 & hous_benhh_z>0 & hous_benhh_c==0 & (dom_oecd==1 | dom_oecd==3) 
		tab ea_hh if vztah==1 & hous_benhh_z>0 & hous_benhh_c==0 & (dom_oecd==1 | dom_oecd==3) 

	* those with positive reported benefit, but zero calculated
		* even HHs with zero income may not receive the housing benefit, because the income should be replaced by MLS if income<MLS ( 27, odst. 3)
		tab ginc_i_hh if vztah==1 & hous_benhh_c>0 & hous_benhh_z==0
		tab inc_hbhh_z if vztah==1 & hous_benhh_c>0 & hous_benhh_z==0
		tab dom_oecd if vztah==1 & hous_benhh_c>0 & hous_benhh_z==0
				
	* deviations
	gen hous_ben_deva = hous_benhh_z - hous_benhh_c  				if (hous_benhh_c>0 | hous_benhh_z>0)
	gen hous_ben_devp = (hous_benhh_z - hous_benhh_c)/hous_benhh_c*100 if (hous_benhh_c>0 | hous_benhh_z>0)
	label variable hous_ben_deva "Housing benefit - absolute deviation"
	label variable hous_ben_devp "Housing benefit - percentage deviation"

	tab hous_ben_deva if vztah==1
	tab hous_ben_devp if vztah==1

	* graph absolute deviation
	scatter hous_ben_deva ginc_i_hh if vztah==1 & (hous_benhh_c>0 | hous_benhh_z>0), saving(hous_ben_deva1, replace) graphregion(color(white) lwidth(large)) title("Housing benefit") subt("Absolute difference")
	scatter hous_ben_deva ginc_i_hh if vztah==1 & (hous_benhh_c>0 | hous_benhh_z>0) & hous_ben_deva>-50000, saving(hous_ben_deva2, replace) graphregion(color(white) lwidth(large)) title("Housing benefit") subt("Absolute difference, if diff>-50,000")
	* graph relative deviation
	scatter hous_ben_devp ginc_i_hh if vztah==1 & (hous_benhh_c>0 | hous_benhh_z>0), saving(hous_ben_devp, replace) graphregion(color(white) lwidth(large)) title("Housing benefit") subt("Percentage difference")

	* graph distribution
	count if (hous_benhh_c>0 | hous_benhh_z>0) & vztah==1
	twoway histogram hous_benhh_c if hous_benhh_c>0 & vztah==1 [fweight=round(pkoef)], start(0) width(2000)  percent fintensity(inten80) lpattern(solid) fcolor(dkorange) lcolor(dkorange) legend(label(1 "Reported"))  || histogram hous_benhh_z if hous_benhh_z>0 & vztah==1 [fweight=round(pkoef)], start(0) width(2000) percent fintensity(inten100) barwidth(1000) legend(label(2 "Calculated")) fcolor(emidblue) lcolor(edkblue) graphregion(color(white) lwidth(large)) ytitle("percent") xtitle(, margin(top)) title("Housing benefit distribution") subtitle("`r(N)' observations")


	****** AID IN MATERIAL NEED  ******
	* at HH level
	gen mat_need_z = hous_supl_z + liv_all_z
	by domac: egen mat_needhh_z = total(mat_need_z)

	* how many HH have positive aid in material need reported and how many computed
	sum mat_needhh_c if vztah==1 & mat_needhh_c>0
	sum mat_needhh_z if vztah==1 & mat_needhh_z>0

	sum mat_needhh_c if vztah==1 & mat_needhh_c>0 & mat_needhh_z==0
	sum mat_needhh_z if vztah==1 & mat_needhh_z>0 & mat_needhh_c==0
		
	* those with positive calculated benefit, but zero reported
		tab ginc_i_hh if vztah==1 & mat_needhh_z>0 & mat_needhh_c==0
		tab dom_oecd if vztah==1 & mat_needhh_z>0 & mat_needhh_c==0 // because these are mainly households of pensioners and unemployed...

		sum ginc_i_hh if vztah==1 & mat_needhh_z>0 & mat_needhh_c==0 & (dom_oecd==1 | dom_oecd==3) // the rest are household with low income...
		sum inc_hbhh_z if vztah==1 & mat_needhh_z>0 & mat_needhh_c==0 & (dom_oecd==1 | dom_oecd==3) 
		tab ea_hh if vztah==1 & mat_needhh_z>0 & mat_needhh_c==0 & (dom_oecd==1 | dom_oecd==3) 

	* those with positive reported benefit, but zero calculated
		* even HHs with zero income may not receive the housing benefit, because the income should be replaced by MLS if income<MLS ( 27, odst. 3)
		tab ginc_i_hh if vztah==1 & mat_needhh_c>0 & mat_needhh_z==0
		tab inc_hbhh_z if vztah==1 & mat_needhh_c>0 & mat_needhh_z==0
		tab dom_oecd if vztah==1 & mat_needhh_c>0 & mat_needhh_z==0
		tab dom_ea if vztah==1 & mat_needhh_c>0 & mat_needhh_z==0
		
	* deviations
	gen mat_need_deva = mat_needhh_z - mat_needhh_c  				if (mat_needhh_c>0 | mat_needhh_z>0)
	gen mat_need_devp = (mat_needhh_z - mat_needhh_c)/mat_needhh_c*100 if (mat_needhh_c>0 | mat_needhh_z>0)
	label variable mat_need_deva "Aid in material need - absolute deviation"
	label variable mat_need_devp "Aid in material need - percentage deviation"

	tab mat_need_deva if vztah==1
	tab mat_need_devp if vztah==1

	* graph absolute deviation
	scatter mat_need_deva ginc_i_hh if vztah==1 & (mat_needhh_c>0 | mat_needhh_z>0), saving(mat_need_deva1, replace) graphregion(color(white) lwidth(large)) title("Aid in material need") subt("Absolute difference")
	scatter mat_need_deva ginc_i_hh if vztah==1 & (mat_needhh_c>0 | mat_needhh_z>0) & mat_need_deva>-50000, saving(mat_need_deva2, replace) graphregion(color(white) lwidth(large)) title("Aid in material need") subt("Absolute difference, if diff>-50,000")
	* graph relative deviation
	scatter mat_need_devp ginc_i_hh if vztah==1 & (mat_needhh_c>0 | mat_needhh_z>0), saving(mat_need_devp, replace) graphregion(color(white) lwidth(large)) title("Aid in material need") subt("Percentage difference")

	* graph distribution
	count if (mat_needhh_c>0 | mat_needhh_z>0) & vztah==1
	twoway histogram mat_needhh_c if mat_needhh_c>0 & vztah==1 [fweight=round(pkoef)], start(0) width(4000)  percent fintensity(inten80) lpattern(solid) fcolor(dkorange) lcolor(dkorange) legend(label(1 "Reported"))  || histogram mat_needhh_z if mat_needhh_z>0 & vztah==1 [fweight=round(pkoef)], start(0) width(4000) percent fintensity(inten100) barwidth(2000) legend(label(2 "Calculated")) fcolor(emidblue) lcolor(edkblue) graphregion(color(white) lwidth(large)) ytitle("percent") xtitle(, margin(top)) title("Aid in material need distribution") subtitle("`r(N)' observations")

	save `dataout', replace
	end

* bencheck wsilctaxben_orig2 wsilctaxben_orig3










