*** THIS DO FILE GENERATES TABLES CHARACTERIZING THE TAX SYSTEM UNDER TAX PARAMETERS `t' *********
*** STORES TABLES IN A LOG-FILE AND SEPARATE TAB FILES (EXCEL)
* 	It runs as a program (taxbentables), in which the argument is a tax regime `t'
* Files in the directory needed to run the do file: taxbenchars`t'.dta - as obtained by running the taxben up to taxbenchars.do

capture program drop taxbentables
program define taxbentables
args t 

	capture log close
	cd output_`t'
	use taxbenchars_`t'
	
	capture mkdir logs_`t' //all tables and log files in folder logs
	cd logs_`t'
	
	
	*** 0. Summary statistics on SILC sample
	* variable to count number of HHs/people in certain cathegory
	gen number = 1
	* Individuals - income and other variables, separately for individual income types
	tabout inc_type [fw=rpkoef] using ind_sumchar_inctax_`t'.xls, replace format(2) cell(N number mean ginc_i mean ginc_w mean ginc_b mean totaltax_i_`t' mean inctax_i_`t' mean payrolltax_i_`t' mean payrolltaxee_w_`t' mean payrolltaxer_w_`t' mean payrolltax_b_`t' mean vek mean dmy_female mean deti) sum
	tabout inc_type [fw=rpkoef] using ind_sumchar_inctax_`t'.xls, append  format(2) cell(N number sd ginc_i sd ginc_w sd ginc_b sd totaltax_i_`t' sd inctax_i_`t' sd payrolltax_i_`t' sd payrolltaxee_w_`t' sd payrolltaxer_w_`t' sd payrolltax_b_`t' sd vek sd dmy_female sd deti) sum
	* Same table without weights (to see the number in the sample)
	tabout inc_type using ind_sumchar_inctax_`t'.xls, append  format(2) cell(N number) sum

	
	log using ind_sum_tax_`t', replace
	*** 1. TABLES AT THE INDIVIDUAL LEVEL
	*** 1.1. Basic summary statistics on taxes on earnings
	sum totaltax_w_`t' if ginc_w >inclb $wep, detail
	sum totaltax_b_`t' if ginc_b >inclb $wep, detail
	sum totaltax_i_`t' if ginc_i >inclb $wep, detail
	
	*** 1.2.Simple Lorenz curves - decile shares in taxes on earnings and incomes 
	* keep in mind that the Nth decile in taxes is not necessarily paid by the people in the Nth income decile
	* taxes on work income
	sumdist totaltax_w_`t' if ginc_w >inclb $wep 
	* taxes on business income
	sumdist totaltax_b_`t' if ginc_b >inclb $wep
	* taxes on all incomes
	sumdist totaltax_i_`t' if ginc_i >inclb $wep
	* work income
	sumdist ginc_w if ginc_w > inclb $wep
	* business income
	sumdist ginc_b if ginc_b > inclb $wep
	* all incomes
	sumdist ginc_i if ginc_i > inclb $wep
	log close

	*** 1.3. Mean incomes, taxes, income shares and tax shares by income deciles
	*** Here the taxes are paid by the income deciles
	local sources "w b i"
	foreach s of local sources {
		tabout dec_ginc_`s' if ginc_`s' > inclb $wep using ind_dec_tax_`s'_`t'.xls, replace format(3) cell(mean ginc_`s' mean totaltax_`s'_`t' mean dec_shr_ginc_`s' mean dec_shr_totaltax_`s'_`t') sum
	}
	* Append the table with all income by shares of business and work income in deciles
	tabout dec_ginc_i if ginc_i > inclb $wep using ind_dec_tax_i_`t'.xls, append format(3) cell(mean dec_shr_i_ginc_w mean dec_shr_i_ginc_b) sum
	
	* Gini coefficients, concentration coefficients, their ratios
	log using ind_sum_gini_`t', replace
	foreach s of local sources {
		* Gini - income
		sgini ginc_`s' if ginc_`s'> inclb $wep
		scalar gini_ginc_`s' = r(coeff)
		* Concentration coeff - total taxes against income
		sgini totaltax_`s'_`t' if ginc_`s' > inclb $wep, s(ginc_`s')
		scalar conc_totaltax_`s'_`t' = r(coeff)
		* Ratio
		scalar ratcg_totaltax_`s'_`t' = conc_totaltax_`s'_`t'/gini_ginc_`s'
		display "Ratio of the tax concentration and income gini, income source = `s'"
		display ratcg_totaltax_`s'_`t'
	}
	log close
	
	
	*** 1.4 TABLES of ATR's, MTR's and PTR's 
	log using ind_sum_atrmtrptr_`t', replace
	* Summary statistics on ATR's
	sum ATR_w_`t' $wep if ginc_w>inclb, detail
	sum ATR_b_`t' $wep if ginc_b>inclb, detail
	sum ATR_i_`t' $wep if ginc_i>inclb, detail
		
	* Summary statistics on MTR's - tax only
	sum mtr_tax_w_`t' $wep if ginc_w>inclb, detail
	sum mtr_tax_b_`t' $wep if ginc_b>inclb, detail
	sum mtr_tax_i_`t' $wep if ginc_i>inclb, detail
	
	* Summary statistics on MTR's - effective (full) rates
	sum mtr_all_w_`t' $wep if ginc_w>inclb, detail
	sum mtr_all_b_`t' $wep if ginc_b>inclb, detail
	sum mtr_all_i_`t' $wep if ginc_i>inclb, detail
	
	* Summary statistics on PTR's - tax only
	sum ptr_tax_w_`t' $wep if ginc_w >inclb & ginc_w<2000000, detail
	sum ptr_tax_b_`t' $wep if ginc_b >inclb & ginc_b<2000000, detail
	sum ptr_tax_i_`t' $wep if ginc_i >inclb & ginc_i<2000000, detail
	
	* Summary statistics on PTR's - effective (full) rates
	sum pptr_all_w_`t' $wep if ginc_w >inclb & ginc_w <2000000, detail
	sum pptr_all_b_`t' $wep if ginc_b >inclb & ginc_b <2000000, detail
	sum pptr_all_i_`t' $wep if ginc_i >inclb & ginc_i <2000000, detail
	
	* Summary stats of PTR for non-working
	sum ptr_tax_w_f_`t' $wep if mzda_f >inclb 	& mzda_f<2000000, detail
	sum ptr_tax_w_p_`t' $wep if mzda_p >(inclb/2) & mzda_p<2000000, detail
	sum ptr_all_w_f_`t' $wep if mzda_f >inclb 	& mzda_f<2000000, detail
	sum ptr_all_w_p_`t' $wep if mzda_p >(inclb/2) & mzda_p<2000000, detail
	log close
	
	
	
	* 1.5 TABULATION (frequencies) OF INTERVALS of ATR's, MTR's and PTR's 
	* the frequencies are already computed and stored in a separate dataset wintervals_`t'.dta
	* separate table for frequencies of taxpayers and incomes
	use ../wintervals_`t', clear
	tabout int_taxrate using ind_int_ATR_`t'.xls, replace format(3) c(mean shrn_ATR_w_`t' mean shrn_ATR_b_`t' mean shrn_ATR_i_`t') sum
	tabout int_taxrate using ind_int_ATR_`t'.xls, append  format(3) c(mean shri_ATR_w_`t' mean shri_ATR_b_`t' mean shri_ATR_i_`t') sum
	
	* Tabulation of intervals of MTR's  - work income
	tabout int_taxrate using ind_int_mtr_w_`t'.xls, replace format(3) c(mean shrn_mtr_tax_w_`t' mean shrn_mtr_ben_w_`t' mean shrn_mtr_all_w_`t') sum
	tabout int_taxrate using ind_int_mtr_w_`t'.xls, append  format(3) c(mean shri_mtr_tax_w_`t' mean shri_mtr_ben_w_`t' mean shri_mtr_all_w_`t') sum

	* Tabulation of intervals of MTR's  - business income
	tabout int_taxrate using ind_int_mtr_b_`t'.xls, replace format(3) c(mean shrn_mtr_tax_b_`t' mean shrn_mtr_ben_b_`t' mean shrn_mtr_all_b_`t') sum
	tabout int_taxrate using ind_int_mtr_b_`t'.xls, append  format(3) c(mean shri_mtr_tax_b_`t' mean shri_mtr_ben_b_`t' mean shri_mtr_all_b_`t') sum

	* Tabulation (frequencies) of intervals of MTR's  - all income
	tabout int_taxrate using ind_int_mtr_i_`t'.xls, replace format(3) c(mean shrn_mtr_tax_i_`t' mean shrn_mtr_ben_i_`t' mean shrn_mtr_all_i_`t') sum
	tabout int_taxrate using ind_int_mtr_i_`t'.xls, append  format(3) c(mean shri_mtr_tax_i_`t' mean shri_mtr_ben_i_`t' mean shri_mtr_all_i_`t') sum

	* Tabulation (frequencies) of intervals of PTR's  - work income
	tabout int_taxrate using ind_int_ptr_w_`t'.xls, replace format(3) c(mean shrn_ptr_tax_w_`t' mean shrn_ptr_ben_w_`t' mean shrn_ptr_all_w_`t') sum
	tabout int_taxrate using ind_int_ptr_w_`t'.xls, append  format(3) c(mean shri_ptr_tax_w_`t' mean shri_ptr_ben_w_`t' mean shri_ptr_all_w_`t') sum
	
	* Tabulation (frequencies) of intervals of PTR's  - business income
	tabout int_taxrate using ind_int_ptr_b_`t'.xls, replace format(3) c(mean shrn_ptr_tax_b_`t' mean shrn_ptr_ben_b_`t' mean shrn_ptr_all_b_`t') sum
	tabout int_taxrate using ind_int_ptr_b_`t'.xls, append  format(3) c(mean shri_ptr_tax_b_`t' mean shri_ptr_ben_b_`t' mean shri_ptr_all_b_`t') sum
	
	* Tabulation (frequencies) of intervals of PTR's  - all income
	tabout int_taxrate using ind_int_ptr_i_`t'.xls, replace format(3) c(mean shrn_ptr_tax_i_`t' mean shrn_ptr_ben_i_`t' mean shrn_ptr_all_i_`t') sum
	tabout int_taxrate using ind_int_ptr_i_`t'.xls, append  format(3) c(mean shri_ptr_tax_i_`t' mean shri_ptr_ben_i_`t' mean shri_ptr_all_i_`t') sum
		
	* Tabulation (frequencies) of intervals of PTR's - non-working full-time
	tabout int_taxrate using ind_int_ptr_wf_`t'.xls, replace format(3) c(mean shrn_ptr_tax_w_f_`t' mean shrn_ptr_ben_w_f_`t' mean shrn_ptr_all_w_f_`t') sum
	tabout int_taxrate using ind_int_ptr_wf_`t'.xls, append  format(3) c(mean shri_ptr_tax_w_f_`t' mean shri_ptr_ben_w_f_`t' mean shri_ptr_all_w_f_`t') sum
	
	* Tabulation (frequencies) of intervals of PTR's - non-working part-time
	tabout int_taxrate using ind_int_ptr_wp_`t'.xls, replace format(3) c(mean shrn_ptr_tax_w_p_`t' mean shrn_ptr_ben_w_p_`t' mean shrn_ptr_all_w_p_`t') sum
	tabout int_taxrate using ind_int_ptr_wp_`t'.xls, append  format(3) c(mean shri_ptr_tax_w_p_`t' mean shri_ptr_ben_w_p_`t' mean shri_ptr_all_w_p_`t') sum	
	use ../taxbenchars_`t', clear
	

	
	*** 1.6 TAXES, ATR's, MTR's and PTR's BY INCOME DECILES
	* Table ATRs by income decile
	tabout dec_ginc_w if ginc_w > inclb $wep using ind_dec_atr_w_`t'.xls, replace format(3) cell(mean ginc_w mean totaltax_w_`t' mean ATR_w_`t' sd ATR_w_`t') sum
	tabout dec_ginc_b if ginc_b > inclb $wep using ind_dec_atr_b_`t'.xls, replace format(3) cell(mean ginc_b mean totaltax_b_`t' mean ATR_b_`t' sd ATR_b_`t') sum
	tabout dec_ginc_i if ginc_i > inclb $wep using ind_dec_atr_i_`t'.xls, replace format(3) cell(mean ginc_i mean totaltax_i_`t' mean ATR_i_`t' sd ATR_i_`t') sum
	
	* Table MTRs by income decile all in one (tax, ben and full MTR)
	tabout dec_ginc_w if ginc_w > inclb $wep using ind_dec_mtr_w_`t'.xls, replace format(3) cell(mean ginc_w mean mtr_tax_w_`t' sd mtr_tax_w_`t' mean mtr_ben_w_`t' sd mtr_ben_w_`t' mean mtr_all_w_`t' sd mtr_all_w_`t') sum
	tabout dec_ginc_b if ginc_b > inclb $wep using ind_dec_mtr_b_`t'.xls, replace format(3) cell(mean ginc_b mean mtr_tax_b_`t' sd mtr_tax_b_`t' mean mtr_ben_b_`t' sd mtr_ben_b_`t' mean mtr_all_b_`t' sd mtr_all_b_`t') sum
	tabout dec_ginc_i if ginc_i > inclb $wep using ind_dec_mtr_i_`t'.xls, replace format(3) cell(mean ginc_i mean mtr_tax_i_`t' sd mtr_tax_i_`t' mean mtr_ben_i_`t' sd mtr_ben_i_`t' mean mtr_all_i_`t' sd mtr_all_i_`t') sum

	* Table PTRs by income decile
	tabout dec_ginc_w if ginc_w > inclb $wep using ind_dec_ptr_w_`t'.xls, replace format(3) cell(mean ginc_w mean ptr_tax_w_`t' sd ptr_tax_w_`t' mean ptr_ben_w_`t' sd ptr_ben_w_`t' mean ptr_all_w_`t' sd ptr_all_w_`t') sum
	tabout dec_ginc_b if ginc_b > inclb $wep using ind_dec_ptr_b_`t'.xls, replace format(3) cell(mean ginc_b mean ptr_tax_b_`t' sd ptr_tax_b_`t' mean ptr_ben_b_`t' sd ptr_ben_b_`t' mean ptr_all_b_`t' sd ptr_all_b_`t') sum
	tabout dec_ginc_i if ginc_i > inclb $wep using ind_dec_ptr_i_`t'.xls, replace format(3) cell(mean ginc_i mean ptr_tax_i_`t' sd ptr_tax_i_`t' mean ptr_ben_i_`t' sd ptr_ben_i_`t' mean ptr_all_i_`t' sd ptr_all_i_`t') sum

	* Table PTRs for non-working by imputed income decile 
	tabout dec_wage_imp if mzda_f > inclb & p==0 $wep using ind_dec_ptr_wf_`t'.xls, replace format(3) cell(mean mzda_f mean ptr_tax_w_f_`t' sd ptr_tax_w_f_`t' mean ptr_ben_w_f_`t' sd ptr_ben_w_f_`t' mean ptr_all_w_f_`t' sd ptr_all_w_f_`t') sum
	tabout dec_wage_imp if mzda_f > inclb & p==0 $wep using ind_dec_ptr_wp_`t'.xls, replace format(3) cell(mean mzda_p mean ptr_tax_w_p_`t' sd ptr_tax_w_p_`t' mean ptr_ben_w_p_`t' sd ptr_ben_w_p_`t' mean ptr_all_w_p_`t' sd ptr_all_w_p_`t') sum
	

			
			
	*** 2. TABLES AT HOUSEHOLD LEVEL ***

	*** 2.0 Basic household characteristics across income deciles
	tabout dec_hhginc_pu if vztah==1 & hhnonpen==1 $wep using hh_sumdec_inctax_`t'.xls, replace format(3) cell(mean hhginc_perunit mean dmy_female mean pres_m mean vek_p mean vek_m mean work_p mean work_m mean detin0 mean detin1 mean detin2 mean detin3 ) sum
	* Households - income and other variables, separately for HH income types
	tabout hhinc_type2 [fw=rpkoef] using hh_sumchar_inctax_`t'.xls, replace format(2) cell(N number mean hhginc_i mean hhginc_w mean hhginc_b mean hhinctax_i_`t' mean hhpayrolltax_i_`t' mean hhtotalben_`t' mean hhtotalben_pos_`t' mean hhnettax_i_`t' mean sj mean deti mean vek_p) sum
	tabout hhinc_type2 [fw=rpkoef] using hh_sumchar_inctax_`t'.xls, append format(2)  cell(N number sd hhginc_i sd hhginc_w sd hhginc_b sd hhinctax_i_`t' sd hhpayrolltax_i_`t' sd hhtotalben_`t' sd hhtotalben_pos_`t' sd hhnettax_i_`t' sd sj sd deti sd vek_p) sum
	* Same table without weights (to see the number in the sample)
	tabout hhinc_type2 using hh_sumchar_inctax_`t'.xls, append format(2) cell(N number) sum

	
	*** 2.1 Basic summary statistics on household taxes and benefits
	log using hh_sum_taxben_`t', replace
	tab hhtotaltax_pos_`t' 		if vztah==1 & hhnonpen==1 $wep
	tab hhtotalben_pos_`t' 		if vztah==1 & hhnonpen==1 $wep
	tab hhnettax_pos_`t'		if vztah==1 & hhnonpen==1 $wep
	sum hhtotaltax_perunit2_`t' if vztah==1 & hhnonpen==1 $wep
	sum hhtotalben_perunit2_`t' if vztah==1 & hhnonpen==1  $wep, detail
	sum hhnettax_perunit_`t'  	if vztah==1 & hhnonpen==1  $wep, detail
	* Summary statistics on ATR's
	sum hhATR_ben_`t' $wep if vztah==1 & hhnonpen==1 , detail
	sum hhATR_tax_`t' $wep if vztah==1 & hhnonpen==1 , detail
	sum hhATR_all_`t' $wep if vztah==1 & hhnonpen==1 , detail
	log close
	
	*** 2.2. Simple Lorenz curves - decile shares in benefits and incomes 
	* keep in mind that the Nth decile in taxes is not necessarily paid by the people in the Nth income decile
	* benefits
	log using hh_sum_gini_`t', replace
	sumdist hhtotalben_perunit2_`t' if vztah==1 & hhnonpen==1 $wep 
	* net taxes
	sumdist hhnettax_perunit_`t' if vztah==1 & hhnonpen==1 $wep
	
	*** 2.2.2. 
	* Gini coefficients, concentration coefficients, their ratios
		* Gini - household income per unit
		sgini hhginc_perunit if vztah==1 & hhnonpen==1 $wep
		scalar gini_hhginc_pu = r(coeff)
		* Gini - household income after taxes per unit
		sgini hhaftertinc_perunit_`t' if vztah==1 & hhnonpen==1 $wep
		scalar gini_hhaftertinc_pu = r(coeff)
		* Gini - household income after benefits per unit
		sgini hhbeninc_perunit_`t' if vztah==1 & hhnonpen==1 $wep
		scalar gini_hhbeninc_pu = r(coeff)		
		* Gini - household income after taxes and beenfits per unit
		sgini hhnetinc_perunit_`t' if vztah==1 & hhnonpen==1 $wep
		scalar gini_hhnetinc_pu = r(coeff)
		
		* Concentration coeff - total taxes against income
		sgini hhtotaltax_perunit_`t' if vztah==1 & hhnonpen==1, s(hhginc_perunit)
		scalar conc_hhtotaltax_pu_`t' = r(coeff)
		sgini hhtotalben_perunit_`t' if vztah==1 & hhnonpen==1, s(hhginc_perunit)
		scalar conc_hhtotalben_pu_`t' = r(coeff)
		sgini hhnettax_perunit_`t' if vztah==1 & hhnonpen==1, s(hhginc_perunit)
		scalar conc_hhnettax_pu_`t' = r(coeff)
		* Ratio
		scalar ratcg_hhnettax_pu_`t' = conc_hhnettax_pu_`t'/gini_hhginc_pu
		display "Ratio of the nettax concentration and income gini, housholds, per unit"
		display ratcg_hhnettax_pu_`t'
	log close 
		
	
	*** 2.3. ATR, mean incomes, benefits, net taxes, income shares and benefits shares by household income deciles and by characteristics
	tabout dec_hhginc_pu 	if vztah==1 & hhnonpen==1 $wep using hh_dec_taxben_pos_`t'.xls, replace format(3) cell(mean hhtotaltax_pos_`t' mean hhtotaltax_perunit2_`t' mean hhtotalben_pos_`t' mean hhtotalben_perunit2_`t' mean hhnettax_pos_`t' mean hhnettax_perunit2_`t') sum
	tabout dec_hhginc_pu 	if vztah==1 & hhnonpen==1 $wep using hh_dec_taxben_shr_`t'.xls, replace format(3) cell(mean dec_shr_hhginc_i mean dec_shr_hhtotaltax_`t' mean dec_shr_hhtotalben_`t' mean dec_shr_hhnettax_`t') sum
	tabout dec_hhginc_pu 	if vztah==1 & hhnonpen==1  $wep using hh_dec_atr_`t'.xls, 		replace format(3) cell(mean hhtotaltax_perunit_`t' mean hhATR_tax_`t' sd hhATR_tax_`t' mean hhtotalben_perunit_`t' mean hhATR_ben_`t' sd hhATR_ben_`t' mean hhnettax_perunit_`t' mean hhATR_all_`t' sd hhATR_all_`t' mean hhnetinc_perunit_`t' sd hhnetinc_perunit_`t') sum
	
		*** mean incomes, benefits, net taxes TOTAL (not per unit)
		* tabout dec_hhginc 	if vztah==1 & hhnonpen==1 $wep using tab_bendeciles_notpu_`t'.xls, replace format(3) cell(N hhginc_i mean hhginc_i mean hhtotaltax_pos_`t' mean hhtotaltax2_i_`t' mean hhtotalben_pos_`t' mean hhtotalben2_`t' mean hhnettax_pos_`t' mean hhnettax2_`t') sum

	*** 2.4. Mean incomes, benefits, net taxes, income shares and benefits shares by characteristics
	* by childless/with children and separately for each type of benefit
	tabout deti2d 							if 	vztah==1 & hhnonpen==1 $wep using hh_char_bentypes_`t'.xls, replace format(3) cell(N vztah mean brth_grhh_pos_`t' mean mat_benhh_pos_`t' mean ch_allhh_pos_`t' mean hous_benhh_pos_`t' mean liv_allhh_pos_`t' mean hous_suplhh_pos_`t' mean unempl_benhh_pos_`t' mean par_allhh_pos_`t' mean other_benhh_pos_`t' mean brth_grhh_perunit2_`t' mean mat_benhh_perunit2_`t' mean ch_allhh_perunit2_`t' mean hous_benhh_perunit2_`t' mean liv_allhh_perunit2_`t' mean hous_suplhh_perunit2_`t' mean unempl_benhh_perunit2_`t' mean par_allhh_perunit2_`t' mean other_benhh_perunit2_`t') sum
	* by number of children, type of income, and economic status of HH
	tabout deti3 hhinc_type if 					vztah==1 & hhnonpen==1  $wep using hh_char_taxben_`t'.xls, replace format(3) cells(N vztah mean hhginc_perunit mean hhtotaltax_perunit_`t' mean hhATR_tax_`t' mean hhtotalben_pos_`t' mean hhtotalben_perunit_`t' mean hhATR_ben_`t' mean hhnettax_perunit_`t' mean hhATR_all_`t' mean hhnetinc_perunit_`t') sum
	tabout work_hh 			if potlfp_pm==1 & 	vztah==1 & hhnonpen==1  $wep using hh_char_taxben_`t'.xls, append  format(3) cells(N vztah mean hhginc_perunit mean hhtotaltax_perunit_`t' mean hhATR_tax_`t' mean hhtotalben_pos_`t' mean hhtotalben_perunit_`t' mean hhATR_ben_`t' mean hhnettax_perunit_`t' mean hhATR_all_`t' mean hhnetinc_perunit_`t') sum
	
	
	* 2.5 Tabulation (frequencies) of intervals of ATR's 
	use ../wintervals_`t', clear
	tabout int_taxrate using hh_int_atr_`t'.xls, replace format(3) c(mean shrn_hhATR_tax_`t' mean shrn_hhATR_ben_`t' mean shrn_hhATR_all_`t') sum
	tabout int_taxrate using hh_int_atr_`t'.xls, append  format(3) c(mean shri_hhATR_tax_`t' mean shri_hhATR_ben_`t' mean shri_hhATR_all_`t') sum
	use ../taxbenchars_`t', clear
	

	*** 2.6. Percentage change in household net income (will work only with reforms)
	capture tabout dec_hhginc_pu if vztah==1 & hhnonpen==1  $wep using hh_dec_netinc_change_`t'.xls, replace format(3) cell(mean pd_hhnetinc_`t' sd pd_hhnetinc_`t') sum
	save ../taxbenchars_`t', replace

	
	*** 3. TAX REVENUES AND BENEFIT EXPENDITURES***
	keep rev_* exp_*
	keep if _n==1
	xpose, clear v
	order _varname v1
	outsheet using "agg_sum_exp_rev_`t'.xls", replace

	
	cd ../..

end //end program taxbentables


